Progress Bar Example
===============================================================================

:download:`progress_bar.enaml <../../../examples/components/progress_bar.enaml>`

.. literalinclude:: ../../../examples/components/progress_bar.enaml
    :language: python

::

 $ enaml-run progress_bar.enaml

.. image:: images/progress_bar.png
